@@ -2,7 +2,7 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2016 Nicolargo <nicolas@nicolargo.com>
+# Copyright (C) 2017 Nicolargo <nicolas@nicolargo.com>
 #
 # Glances is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -22,7 +22,6 @@
 import socket
 import sys
 
-from glances import __appname__
 from glances.globals import BSD
 from glances.logger import logger
 
@@ -48,8 +47,8 @@ if zeroconf_tag:
 
 # Global var
 # Recent versions of the zeroconf python package doesnt like a zeroconf type that ends with '._tcp.'.
-# Correct issue: zeroconf problem with zeroconf_type = "_%s._tcp." % __appname__ #888
-zeroconf_type = "_%s._tcp.local." % __appname__
+# Correct issue: zeroconf problem with zeroconf_type = "_%s._tcp." % 'glances' #888
+zeroconf_type = "_%s._tcp.local." % 'glances'
 
 
 class AutoDiscovered(object):
