@@ -2,7 +2,7 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2015 Nicolargo <nicolas@nicolargo.com>
+# Copyright (C) 2017 Nicolargo <nicolas@nicolargo.com>
 #
 # Glances is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -26,7 +26,8 @@ import sys
 # Note: Somes libs depends of OS
 BSD = sys.platform.find('bsd') != -1
 LINUX = sys.platform.startswith('linux')
-OSX = sys.platform.startswith('darwin')
+MACOS = sys.platform.startswith('darwin')
+SUNOS = sys.platform.startswith('sunos')
 WINDOWS = sys.platform.startswith('win')
 
 # Path definitions
