@@ -2,7 +2,7 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2015 Nicolargo <nicolas@nicolargo.com>
+# Copyright (C) 2017 Nicolargo <nicolas@nicolargo.com>
 #
 # Glances is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -24,7 +24,7 @@ import os
 import sys
 import tempfile
 
-from glances import __appname__, __version__, psutil_version
+from glances import __version__, psutil_version
 from glances.compat import input
 from glances.config import Config
 from glances.globals import LINUX, WINDOWS
@@ -37,9 +37,7 @@ class GlancesMain(object):
 
     # Default stats' refresh time is 3 seconds
     refresh_time = 3
-
     # Set the default cache lifetime to 1 second (only for server)
-    # !!! Todo: To be configurable (=> https://github.com/nicolargo/glances/issues/901)
     cached_time = 1
     # By default, Glances is ran in standalone mode (no client/server)
     client_tag = False
@@ -63,7 +61,7 @@ Monitor local machine with the Web interface (Web UI):\n\
   Glances web server started on http://0.0.0.0:61208/\n\
 \n\
 Monitor local machine and export stats to a CSV file (standalone mode):\n\
-  $ glances --export-csv\n\
+  $ glances --export-csv /tmp/glances.csv\n\
 \n\
 Monitor local machine and export stats to a InfluxDB server with 5s refresh time (standalone mode):\n\
   $ glances -t 5 --export-influxdb\n\
@@ -83,13 +81,14 @@ Start the client browser (browser mode):\n\
 
     def __init__(self):
         """Manage the command line arguments."""
+        # Read the command line arguments
         self.args = self.parse_args()
 
     def init_args(self):
         """Init all the command line arguments."""
         version = "Glances v" + __version__ + " with psutil v" + psutil_version
         parser = argparse.ArgumentParser(
-            prog=__appname__,
+            prog='glances',
             conflict_handler='resolve',
             formatter_class=argparse.RawDescriptionHelpFormatter,
             epilog=self.example_of_use)
@@ -100,65 +99,77 @@ Start the client browser (browser mode):\n\
         parser.add_argument('-C', '--config', dest='conf_file',
                             help='path to the configuration file')
         # Enable or disable option on startup
+        parser.add_argument('--disable-alert', action='store_true', default=False,
+                            dest='disable_alert', help='disable alert module')
+        parser.add_argument('--disable-amps', action='store_true', default=False,
+                            dest='disable_amps', help='disable applications monitoring process (AMP) module')
+        parser.add_argument('--disable-cpu', action='store_true', default=False,
+                            dest='disable_cpu', help='disable CPU module')
+        parser.add_argument('--disable-diskio', action='store_true', default=False,
+                            dest='disable_diskio', help='disable disk I/O module')
+        parser.add_argument('--disable-docker', action='store_true', default=False,
+                            dest='disable_docker', help='disable Docker module')
+        parser.add_argument('--disable-folders', action='store_true', default=False,
+                            dest='disable_folders', help='disable folder module')
+        parser.add_argument('--disable-fs', action='store_true', default=False,
+                            dest='disable_fs', help='disable filesystem module')
+        parser.add_argument('--disable-gpu', action='store_true', default=False,
+                            dest='disable_gpu', help='disable GPU module')
+        parser.add_argument('--disable-hddtemp', action='store_true', default=False,
+                            dest='disable_hddtemp', help='disable HD temperature module')
+        parser.add_argument('--disable-ip', action='store_true', default=False,
+                            dest='disable_ip', help='disable IP module')
+        parser.add_argument('--disable-load', action='store_true', default=False,
+                            dest='disable_load', help='disable load module')
+        parser.add_argument('--disable-mem', action='store_true', default=False,
+                            dest='disable_mem', help='disable memory module')
+        parser.add_argument('--disable-memswap', action='store_true', default=False,
+                            dest='disable_memswap', help='disable memory swap module')
+        parser.add_argument('--disable-network', action='store_true', default=False,
+                            dest='disable_network', help='disable network module')
+        parser.add_argument('--disable-now', action='store_true', default=False,
+                            dest='disable_now', help='disable current time module')
+        parser.add_argument('--disable-ports', action='store_true', default=False,
+                            dest='disable_ports', help='disable ports scanner module')
+        parser.add_argument('--disable-process', action='store_true', default=False,
+                            dest='disable_process', help='disable process module')
+        parser.add_argument('--disable-raid', action='store_true', default=False,
+                            dest='disable_raid', help='disable RAID module')
+        parser.add_argument('--disable-sensors', action='store_true', default=False,
+                            dest='disable_sensors', help='disable sensors module')
+        parser.add_argument('--disable-wifi', action='store_true', default=False,
+                            dest='disable_wifi', help='disable wifi module')
+        parser.add_argument('-0', '--disable-irix', action='store_true', default=False,
+                            dest='disable_irix', help='task\'s cpu usage will be divided by the total number of CPUs')
+        parser.add_argument('-1', '--percpu', action='store_true', default=False,
+                            dest='percpu', help='start Glances in per CPU mode')
+        parser.add_argument('-2', '--disable-left-sidebar', action='store_true',
+                            default=False, dest='disable_left_sidebar',
+                            help='disable network, disk I/O, FS and sensors modules')
         parser.add_argument('-3', '--disable-quicklook', action='store_true', default=False,
                             dest='disable_quicklook', help='disable quick look module')
         parser.add_argument('-4', '--full-quicklook', action='store_true', default=False,
                             dest='full_quicklook', help='disable all but quick look and load')
-        parser.add_argument('--disable-cpu', action='store_true', default=False,
-                            dest='disable_cpu', help='disable CPU module')
-        parser.add_argument('--disable-mem', action='store_true', default=False,
-                            dest='disable_mem', help='disable memory module')
-        parser.add_argument('--disable-swap', action='store_true', default=False,
-                            dest='disable_swap', help='disable swap module')
-        parser.add_argument('--disable-load', action='store_true', default=False,
-                            dest='disable_load', help='disable load module')
-        parser.add_argument('--disable-network', action='store_true', default=False,
-                            dest='disable_network', help='disable network module')
-        parser.add_argument('--disable-ports', action='store_true', default=False,
-                            dest='disable_ports', help='disable ports scanner module')
-        parser.add_argument('--disable-ip', action='store_true', default=False,
-                            dest='disable_ip', help='disable IP module')
-        parser.add_argument('--disable-diskio', action='store_true', default=False,
-                            dest='disable_diskio', help='disable disk I/O module')
-        parser.add_argument('--disable-irq', action='store_true', default=False,
-                            dest='disable_irq', help='disable IRQ module'),
-        parser.add_argument('--disable-fs', action='store_true', default=False,
-                            dest='disable_fs', help='disable filesystem module')
-        parser.add_argument('--disable-folder', action='store_true', default=False,
-                            dest='disable_folder', help='disable folder module')
-        parser.add_argument('--disable-sensors', action='store_true', default=False,
-                            dest='disable_sensors', help='disable sensors module')
-        parser.add_argument('--disable-hddtemp', action='store_true', default=False,
-                            dest='disable_hddtemp', help='disable HD temperature module')
-        parser.add_argument('--disable-raid', action='store_true', default=False,
-                            dest='disable_raid', help='disable RAID module')
-        parser.add_argument('--disable-docker', action='store_true', default=False,
-                            dest='disable_docker', help='disable Docker module')
         parser.add_argument('-5', '--disable-top', action='store_true',
                             default=False, dest='disable_top',
                             help='disable top menu (QL, CPU, MEM, SWAP and LOAD)')
-        parser.add_argument('-2', '--disable-left-sidebar', action='store_true',
-                            default=False, dest='disable_left_sidebar',
-                            help='disable network, disk I/O, FS and sensors modules')
-        parser.add_argument('--disable-process', action='store_true', default=False,
-                            dest='disable_process', help='disable process module')
-        parser.add_argument('--disable-amps', action='store_true', default=False,
-                            dest='disable_amps', help='disable applications monitoring process (AMP) module')
-        parser.add_argument('--disable-log', action='store_true', default=False,
-                            dest='disable_log', help='disable log module')
+        parser.add_argument('-6', '--meangpu', action='store_true', default=False,
+                            dest='meangpu', help='start Glances in mean GPU mode')
         parser.add_argument('--disable-history', action='store_true', default=False,
                             dest='disable_history', help='disable stats history')
         parser.add_argument('--disable-bold', action='store_true', default=False,
                             dest='disable_bold', help='disable bold mode in the terminal')
         parser.add_argument('--disable-bg', action='store_true', default=False,
                             dest='disable_bg', help='disable background colors in the terminal')
+        parser.add_argument('--enable-irq', action='store_true', default=False,
+                            dest='enable_irq', help='enable IRQ module'),
         parser.add_argument('--enable-process-extended', action='store_true', default=False,
                             dest='enable_process_extended', help='enable extended stats on top process')
         # Export modules feature
         parser.add_argument('--export-graph', action='store_true', default=None,
                             dest='export_graph', help='export stats to graphs')
         parser.add_argument('--path-graph', default=tempfile.gettempdir(),
-                            dest='path_graph', help='set the export path for graphs (default is {0})'.format(tempfile.gettempdir()))
+                            dest='path_graph', help='set the export path for graphs (default is {})'.format(tempfile.gettempdir()))
         parser.add_argument('--export-csv', default=None,
                             dest='export_csv', help='export stats to a CSV file')
         parser.add_argument('--export-influxdb', action='store_true', default=False,
@@ -175,6 +186,10 @@ Start the client browser (browser mode):\n\
                             dest='export_rabbitmq', help='export stats to rabbitmq broker (pika lib needed)')
         parser.add_argument('--export-riemann', action='store_true', default=False,
                             dest='export_riemann', help='export stats to riemann broker (bernhard lib needed)')
+        parser.add_argument('--export-couchdb', action='store_true', default=False,
+                            dest='export_couchdb', help='export stats to a CouchDB server (couch lib needed)')
+        parser.add_argument('--export-zeromq', action='store_true', default=False,
+                            dest='export_zeromq', help='export stats to a ZeroMQ server (pyzmq lib needed)')
         # Client/Server option
         parser.add_argument('-c', '--client', dest='client',
                             help='connect to a Glances server by IPv4/IPv6 address or hostname')
@@ -208,6 +223,10 @@ Start the client browser (browser mode):\n\
                             dest='time', help='set refresh time in seconds [default: {} sec]'.format(self.refresh_time))
         parser.add_argument('-w', '--webserver', action='store_true', default=False,
                             dest='webserver', help='run Glances in web server mode (bottle needed)')
+        parser.add_argument('--cached-time', default=self.cached_time, type=int,
+                            dest='cached_time', help='set the server cache time [default: {} sec]'.format(self.cached_time))
+        parser.add_argument('--open-web-browser', action='store_true', default=False,
+                            dest='open_web_browser', help='try to open the Web UI in the default Web browser')
         # Display options
         parser.add_argument('-q', '--quiet', default=False, action='store_true',
                             dest='quiet', help='do not display the curses interface')
@@ -215,8 +234,6 @@ Start the client browser (browser mode):\n\
                             dest='process_filter', help='set the process filter pattern (regular expression)')
         parser.add_argument('--process-short-name', action='store_true', default=False,
                             dest='process_short_name', help='force short name for processes name')
-        parser.add_argument('-0', '--disable-irix', action='store_true', default=False,
-                            dest='disable_irix', help='task\'s cpu usage will be divided by the total number of CPUs')
         if not WINDOWS:
             parser.add_argument('--hide-kernel-threads', action='store_true', default=False,
                                 dest='no_kernel_threads', help='hide kernel threads in process list')
@@ -231,8 +248,6 @@ Start the client browser (browser mode):\n\
                             dest='diskio_iops', help='show IO per second in the DiskIO plugin')
         parser.add_argument('--fahrenheit', action='store_true', default=False,
                             dest='fahrenheit', help='display temperature in Fahrenheit (default is Celsius)')
-        parser.add_argument('-1', '--percpu', action='store_true', default=False,
-                            dest='percpu', help='start Glances in per CPU mode')
         parser.add_argument('--fs-free-space', action='store_true', default=False,
                             dest='fs_free_space', help='display FS free space instead of used')
         parser.add_argument('--theme-white', action='store_true', default=False,
@@ -275,11 +290,14 @@ Start the client browser (browser mode):\n\
             args.password_prompt = True
             # Prompt username
             if args.server:
-                args.username = self.__get_username(description='Define the Glances server username: ')
+                args.username = self.__get_username(
+                    description='Define the Glances server username: ')
             elif args.webserver:
-                args.username = self.__get_username(description='Define the Glances webserver username: ')
+                args.username = self.__get_username(
+                    description='Define the Glances webserver username: ')
             elif args.client:
-                args.username = self.__get_username(description='Enter the Glances server username: ')
+                args.username = self.__get_username(
+                    description='Enter the Glances server username: ')
         else:
             # Default user name is 'glances'
             args.username = self.username
@@ -288,17 +306,20 @@ Start the client browser (browser mode):\n\
             # Interactive or file password
             if args.server:
                 args.password = self.__get_password(
-                    description='Define the Glances server password ({} username): '.format(args.username),
+                    description='Define the Glances server password ({} username): '.format(
+                        args.username),
                     confirm=True,
                     username=args.username)
             elif args.webserver:
                 args.password = self.__get_password(
-                    description='Define the Glances webserver password ({} username): '.format(args.username),
+                    description='Define the Glances webserver password ({} username): '.format(
+                        args.username),
                     confirm=True,
                     username=args.username)
             elif args.client:
                 args.password = self.__get_password(
-                    description='Enter the Glances server password ({} username): '.format(args.username),
+                    description='Enter the Glances server password ({} username): '.format(
+                        args.username),
                     clear=True,
                     username=args.username)
         else:
@@ -318,7 +339,7 @@ Start the client browser (browser mode):\n\
             args.disable_quicklook = False
             args.disable_cpu = True
             args.disable_mem = True
-            args.disable_swap = True
+            args.disable_memswap = True
             args.disable_load = False
 
         # Manage disable_top option
@@ -327,29 +348,40 @@ Start the client browser (browser mode):\n\
             args.disable_quicklook = True
             args.disable_cpu = True
             args.disable_mem = True
-            args.disable_swap = True
+            args.disable_memswap = True
             args.disable_load = True
 
         # Control parameter and exit if it is not OK
         self.args = args
 
         # Export is only available in standalone or client mode (issue #614)
-        export_tag = args.export_csv or args.export_elasticsearch or args.export_statsd or args.export_influxdb or args.export_cassandra or args.export_opentsdb or args.export_rabbitmq
+        export_tag = args.export_csv or \
+            args.export_elasticsearch or \
+            args.export_statsd or \
+            args.export_influxdb or \
+            args.export_cassandra or \
+            args.export_opentsdb or \
+            args.export_rabbitmq or \
+            args.export_couchdb
         if not (self.is_standalone() or self.is_client()) and export_tag:
-            logger.critical("Export is only available in standalone or client mode")
+            logger.critical(
+                "Export is only available in standalone or client mode")
             sys.exit(2)
 
         # Filter is only available in standalone mode
         if args.process_filter is not None and not self.is_standalone():
-            logger.critical("Process filter is only available in standalone mode")
+            logger.critical(
+                "Process filter is only available in standalone mode")
             sys.exit(2)
 
         # Check graph output path
         if args.export_graph and args.path_graph is not None:
             if not os.access(args.path_graph, os.W_OK):
-                logger.critical("Graphs output path {0} do not exist or is not writable".format(args.path_graph))
+                logger.critical(
+                    "Graphs output path {} doesn't exist or is not writable".format(args.path_graph))
                 sys.exit(2)
-            logger.debug("Graphs output path is set to {0}".format(args.path_graph))
+            logger.debug(
+                "Graphs output path is set to {}".format(args.path_graph))
 
         # For export graph, history is mandatory
         if args.export_graph and args.disable_history:
