@@ -2,7 +2,7 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2016 Nicolargo <nicolas@nicolargo.com>
+# Copyright (C) 2017 Nicolargo <nicolas@nicolargo.com>
 #
 # Glances is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -32,8 +32,8 @@ except ImportError:
 else:
     outdated_tag = True
 
-from glances import __version__, __appname__
-from glances.globals import BSD, LINUX, OSX, WINDOWS
+from glances import __version__
+from glances.globals import BSD, LINUX, MACOS, WINDOWS
 from glances.logger import logger
 
 
@@ -155,12 +155,11 @@ class Outdated(object):
         if LINUX or BSD:
             return os.path.join(os.environ.get('XDG_CONFIG_HOME') or
                                 os.path.expanduser('~/.config'),
-                                __appname__)
-        elif OSX:
-            return os.path.join(os.path.expanduser('~/Library/Application Support/'),
-                                __appname__)
+                                'glances')
+        elif MACOS:
+            return os.path.expanduser('~/Library/Application Support/glances')
         elif WINDOWS:
-            return os.path.join(os.environ.get('APPDATA'), __appname__)
+            return os.path.join(os.environ.get('APPDATA'), 'glances')
 
     def _update_pypi_version(self):
         """Get the latest Pypi version (as a string) via the Restful JSON API"""
