@@ -2,7 +2,7 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2015 Nicolargo <nicolas@nicolargo.com>
+# Copyright (C) 2017 Nicolargo <nicolas@nicolargo.com>
 #
 # Glances is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -26,9 +26,8 @@ import sys
 import uuid
 from io import open
 
-from glances import __appname__
 from glances.compat import b, input
-from glances.globals import BSD, LINUX, OSX, WINDOWS
+from glances.globals import BSD, LINUX, MACOS, WINDOWS
 from glances.logger import logger
 
 
@@ -45,13 +44,13 @@ class GlancesPassword(object):
     def get_password_path(self):
         r"""Get the path where the password file will be stored.
 
-        * Linux and BSD: ~/.config/glances
-        * OS X: ~/Library/glances
+        * Linux and *BSD: ~/.config/glances
+        * macOS: ~/Library/glances
         * Windows: %APPDATA%\glances
         """
         if LINUX or BSD:
             app_path = os.environ.get('XDG_CONFIG_HOME') or os.path.expanduser('~/.config')
-        elif OSX:
+        elif MACOS:
             app_path = os.path.join(os.environ.get('HOME'), 'Library')
         elif WINDOWS:
             app_path = os.environ.get('APPDATA')
@@ -59,7 +58,7 @@ class GlancesPassword(object):
             app_path = '.'
 
         # Append the Glances folder
-        app_path = os.path.join(app_path, __appname__)
+        app_path = os.path.join(app_path, 'glances')
 
         return app_path
 
@@ -101,7 +100,7 @@ class GlancesPassword(object):
         """
         if os.path.exists(self.password_filepath) and not clear:
             # If the password file exist then use it
-            logger.info("Read password from file {0}".format(self.password_filepath))
+            logger.info("Read password from file {}".format(self.password_filepath))
             password = self.load_password()
         else:
             # password_sha256 is the plain SHA-256 password
@@ -138,7 +137,7 @@ class GlancesPassword(object):
             try:
                 os.makedirs(self.password_path)
             except OSError as e:
-                logger.error("Cannot create Glances directory: {0}".format(e))
+                logger.error("Cannot create Glances directory: {}".format(e))
                 return
 
         # Create/overwrite the password file
