@@ -2,7 +2,7 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2015 Nicolargo <nicolas@nicolargo.com>
+# Copyright (C) 2017 Nicolargo <nicolas@nicolargo.com>
 #
 # Glances is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -66,6 +66,9 @@ class Plugin(GlancesPlugin):
         # value: instance of ThreadDockerGrabber
         self.thread_list = {}
 
+        # Init the stats
+        self.reset()
+
     def exit(self):
         """Overwrite the exit method to close threads"""
         for t in itervalues(self.thread_list):
@@ -90,18 +93,43 @@ class Plugin(GlancesPlugin):
             logger.debug("Docker export error {}".format(e))
         return ret
 
-    def connect(self, version=None):
-        """Connect to the Docker server."""
+    def __connect_old(self, version):
+        """Connect to the Docker server with the 'old school' method"""
+        # Glances is compatible with both API 2.0 and <2.0
+        # (thanks to the @bacondropped patch)
+        if hasattr(docker, 'APIClient'):
+            # Correct issue #1000 for API 2.0
+            init_docker = docker.APIClient
+        elif hasattr(docker, 'Client'):
+            # < API 2.0
+            init_docker = docker.Client
+        else:
+            # Can not found init method (new API version ?)
+            logger.error("Can not found any way to init the Docker API")
+            return None
         # Init connection to the Docker API
         try:
             if version is None:
-                ret = docker.Client(base_url='unix://var/run/docker.sock')
+                ret = init_docker(base_url='unix://var/run/docker.sock')
             else:
-                ret = docker.Client(base_url='unix://var/run/docker.sock',
-                                    version=version)
+                ret = init_docker(base_url='unix://var/run/docker.sock',
+                                  version=version)
         except NameError:
             # docker lib not found
             return None
+
+        return ret
+
+    def connect(self, version=None):
+        """Connect to the Docker server."""
+        if hasattr(docker, 'from_env') and version is not None:
+            # Connect to Docker using the default socket or
+            # the configuration in your environment
+            ret = docker.from_env()
+        else:
+            ret = self.__connect_old(version=version)
+
+        # Check the server connection with the version() method
         try:
             ret.version()
         except requests.exceptions.ConnectionError as e:
@@ -141,22 +169,28 @@ class Plugin(GlancesPlugin):
         """Reset/init the stats."""
         self.stats = {}
 
+    @GlancesPlugin._check_decorator
     @GlancesPlugin._log_result_decorator
     def update(self):
         """Update Docker stats using the input method."""
+        global docker_tag
+
         # Reset stats
         self.reset()
 
         # Get the current Docker API client
         if not self.docker_client:
             # First time, try to connect to the server
-            self.docker_client = self.connect()
-            if self.docker_client is None:
-                global docker_tag
+            try:
+                self.docker_client = self.connect()
+            except Exception:
                 docker_tag = False
+            else:
+                if self.docker_client is None:
+                    docker_tag = False
 
         # The Docker-py lib is mandatory
-        if not docker_tag or (self.args is not None and self.args.disable_docker):
+        if not docker_tag:
             return self.stats
 
         if self.input_method == 'local':
@@ -256,7 +290,7 @@ class Plugin(GlancesPlugin):
             cpu_new['nb_core'] = len(all_stats['cpu_stats']['cpu_usage']['percpu_usage'] or [])
         except KeyError as e:
             # all_stats do not have CPU information
-            logger.debug("Can not grab CPU usage for container {0} ({1})".format(container_id, e))
+            logger.debug("Cannot grab CPU usage for container {} ({})".format(container_id, e))
             logger.debug(all_stats)
         else:
             # Previous CPU stats stored in the cpu_old variable
@@ -327,7 +361,7 @@ class Plugin(GlancesPlugin):
             netcounters = all_stats["networks"]
         except KeyError as e:
             # all_stats do not have NETWORK information
-            logger.debug("Can not grab NET usage for container {0} ({1})".format(container_id, e))
+            logger.debug("Cannot grab NET usage for container {} ({})".format(container_id, e))
             logger.debug(all_stats)
             # No fallback available...
             return network_new
@@ -351,14 +385,14 @@ class Plugin(GlancesPlugin):
             # XML/RPC API, which would otherwise be overly difficult work
             # for users of the API
             try:
-                network_new['time_since_update'] = getTimeSinceLastUpdate('docker_net_{0}'.format(container_id))
+                network_new['time_since_update'] = getTimeSinceLastUpdate('docker_net_{}'.format(container_id))
                 network_new['rx'] = netcounters["eth0"]["rx_bytes"] - self.netcounters_old[container_id]["eth0"]["rx_bytes"]
                 network_new['tx'] = netcounters["eth0"]["tx_bytes"] - self.netcounters_old[container_id]["eth0"]["tx_bytes"]
                 network_new['cumulative_rx'] = netcounters["eth0"]["rx_bytes"]
                 network_new['cumulative_tx'] = netcounters["eth0"]["tx_bytes"]
-            except KeyError:
+            except KeyError as e:
                 # all_stats do not have INTERFACE information
-                logger.debug("Can not grab network interface usage for container {0} ({1})".format(container_id, e))
+                logger.debug("Cannot grab network interface usage for container {} ({})".format(container_id, e))
                 logger.debug(all_stats)
 
             # Save stats to compute next bitrate
@@ -385,7 +419,7 @@ class Plugin(GlancesPlugin):
             iocounters = all_stats["blkio_stats"]
         except KeyError as e:
             # all_stats do not have io information
-            logger.debug("Can not grab block IO usage for container {0} ({1})".format(container_id, e))
+            logger.debug("Cannot grab block IO usage for container {} ({})".format(container_id, e))
             logger.debug(all_stats)
             # No fallback available...
             return io_new
@@ -434,13 +468,59 @@ class Plugin(GlancesPlugin):
         """Return the user ticks by reading the environment variable."""
         return os.sysconf(os.sysconf_names['SC_CLK_TCK'])
 
+    def get_stats_action(self):
+        """Return stats for the action
+        Docker will return self.stats['containers']"""
+        return self.stats['containers']
+
+    def update_views(self):
+        """Update stats views."""
+        # Call the father's method
+        super(Plugin, self).update_views()
+
+        if 'containers' not in self.stats:
+            return False
+
+        # Add specifics informations
+        # Alert
+        for i in self.stats['containers']:
+            # Init the views for the current container (key = container name)
+            self.views[i[self.get_key()]] = {'cpu': {}, 'mem': {}}
+            # CPU alert
+            if 'cpu' in i and 'total' in i['cpu']:
+                # Looking for specific CPU container threasold in the conf file
+                alert = self.get_alert(i['cpu']['total'],
+                                       header=i['name'] + '_cpu',
+                                       action_key=i['name'])
+                if alert == 'DEFAULT':
+                    # Not found ? Get back to default CPU threasold value
+                    alert = self.get_alert(i['cpu']['total'], header='cpu')
+                self.views[i[self.get_key()]]['cpu']['decoration'] = alert
+            # MEM alert
+            if 'memory' in i and 'usage' in i['memory']:
+                # Looking for specific MEM container threasold in the conf file
+                alert = self.get_alert(i['memory']['usage'],
+                                       maximum=i['memory']['limit'],
+                                       header=i['name'] + '_mem',
+                                       action_key=i['name'])
+                if alert == 'DEFAULT':
+                    # Not found ? Get back to default MEM threasold value
+                    alert = self.get_alert(i['memory']['usage'],
+                                           maximum=i['memory']['limit'],
+                                           header='mem')
+                self.views[i[self.get_key()]]['mem']['decoration'] = alert
+
+        return True
+
     def msg_curse(self, args=None):
         """Return the dict to display in the curse interface."""
         # Init the return message
         ret = []
 
         # Only process if stats exist (and non null) and display plugin enable...
-        if not self.stats or args.disable_docker or len(self.stats['containers']) == 0:
+        if not self.stats \
+           or len(self.stats['containers']) == 0 \
+           or self.is_disable():
             return ret
 
         # Build the string message
@@ -502,13 +582,17 @@ class Plugin(GlancesPlugin):
                 msg = '{:>6.1f}'.format(container['cpu']['total'])
             except KeyError:
                 msg = '{:>6}'.format('?')
-            ret.append(self.curse_add_line(msg))
+            ret.append(self.curse_add_line(msg, self.get_views(item=container['name'],
+                                                               key='cpu',
+                                                               option='decoration')))
             # MEM
             try:
                 msg = '{:>7}'.format(self.auto_unit(container['memory']['usage']))
             except KeyError:
                 msg = '{:>7}'.format('?')
-            ret.append(self.curse_add_line(msg))
+            ret.append(self.curse_add_line(msg, self.get_views(item=container['name'],
+                                                               key='mem',
+                                                               option='decoration')))
             try:
                 msg = '{:>7}'.format(self.auto_unit(container['memory']['limit']))
             except KeyError:
